@@ -11,7 +11,7 @@ use Log::Log4perl qw(:easy);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
 
 # ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '0.84_02'; # VERSION
+our $VERSION = '0.90_01'; # VERSION
 
 
 has secret => rand;
@@ -96,6 +96,62 @@ sub startup {
     INFO "max message size = " . format_bytes($max_size) . " ($max_size)";
 }
 
+sub sanity_check
+{
+    my($self) = @_;
+
+    return 0 unless $self->SUPER::sanity_check;
+
+    my $sane = 1;
+    
+    my($url) = grep { $_ eq $self->config->url } map { $_->{url} } @{ $self->config->{servers} };
+    
+    unless(defined $url)
+    {
+        say "url for this server is not in the disk map";
+        $sane = 0;
+    }
+    
+    $sane;
+}
+
+sub generate_config {
+    my $self = shift;
+
+    my $root = $ENV{CLUSTERICIOUS_CONF_DIR} || $ENV{HOME};
+
+    return {
+     dirs => [
+         [qw(etc)],
+         [qw(var log)],
+         [qw(var run)],
+         [qw(var lib yars data)],
+     ],
+     files => { 'Yars.conf' => <<'CONF', 'log4perl.conf' => <<CONF2 } };
+---
+% my $root = $ENV{HOME};
+start_mode : 'hypnotoad'
+url : http://localhost:9999
+hypnotoad :
+  pid_file : <%= $root %>/var/run/yars.pid
+  listen :
+     - http://localhost:9999
+servers :
+- url : http://localhost:9999
+  disks :
+    - root : <%= $root %>/var/lib/yars/data
+      buckets : [ <%= join ',', '0'..'9', 'a' .. 'f' %> ]
+CONF
+log4perl.rootLogger=TRACE, LOGFILE
+log4perl.logger.Mojolicious=TRACE
+log4perl.appender.LOGFILE=Log::Log4perl::Appender::File
+log4perl.appender.LOGFILE.filename=$root/var/log/yars.log
+log4perl.appender.LOGFILE.mode=append
+log4perl.appender.LOGFILE.layout=PatternLayout
+log4perl.appender.LOGFILE.layout.ConversionPattern=[%d{ISO8601}] [%7Z] %5p: %m%n
+CONF2
+}
+
 
 1;
 
@@ -108,7 +164,7 @@ Yars - Yet Another RESTful-Archive Service
 
 =head1 VERSION
 
-version 0.84_02
+version 0.90_01
 
 =head1 DESCRIPTION
 
@@ -262,21 +318,19 @@ Called by the server to start up, we change
 the object classes to use Yars::Message::Request
 for incoming requests.
 
-=head1 AUTHORS
-
-Current maintainer: Graham Ollis <plicease@cpan.org>
-
-Previous maintainer: Marty Brandon
-
-Original author: Brian Duggan
-
 =head1 SEE ALSO
 
 L<Yars::Client>
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+original author: Marty Brandon
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Brian Duggan
 
 =head1 COPYRIGHT AND LICENSE
 
