@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '0.84_02'; # VERSION
+our $VERSION = '0.90_01'; # VERSION
 
 
 use strict;
@@ -494,7 +494,6 @@ post '/check/manifest' => sub {
     for my $server (keys %remote) {
         TRACE "Looking for manifest files on $server";
         my $content = Mojo::JSON->new->encode({ files => $remote{$server} });
-        $DB::single = 1;
         my $tx = $c->tools->_ua->post(
             "$server/check/manifest?show_found=1&show_corrupt=".($c->param("show_corrupt")//''),
             { "Content-type" => "application/json", "Connection" => "Close" }, $content );
@@ -600,7 +599,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 0.84_02
+version 0.90_01
 
 =head1 ROUTES
 
@@ -656,7 +655,13 @@ L<Yars>, L<Yars::Client>
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+original author: Marty Brandon
+
+current maintainer: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Brian Duggan
 
 =head1 COPYRIGHT AND LICENSE
 
